"""tgdl - High-performance Telegram media downloader CLI tool."""

__version__ = "1.0.1"
__author__ = "kavidu-dilhara"
__license__ = "MIT"

from tgdl.cli import main

__all__ = ["main", "__version__"]
